@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -337,7 +337,7 @@ merge_opts(const char *opts1, const char *opts2)
     if (amu_hasmntopt(&mnt2, oneopt) || amu_hasmntopt(&mnt2, revoneopt))
       continue;
     /* add option to returned string */
-    if (newstr && newstr[0]) {
+    if (newstr[0]) {
       xstrlcat(newstr, ",", len);
       xstrlcat(newstr, tmpstr, len);
     } else {
@@ -346,7 +346,7 @@ merge_opts(const char *opts1, const char *opts2)
   }
 
   /* finally, append opts2 itself */
-  if (newstr && newstr[0]) {
+  if (newstr[0]) {
     xstrlcat(newstr, ",", len);
     xstrlcat(newstr, opts2, len);
   } else {
