@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -289,10 +289,10 @@ init_global_options(void)
   /* local domain */
   gopt.sub_domain = NULL;
 
-  /* reset NFS retransmit counter and retry interval */
+  /* reset NFS (and toplvl) retransmit counter and retry interval */
   for (i=0; i<AMU_TYPE_MAX; ++i) {
-    gopt.amfs_auto_retrans[i] = -1;
-    gopt.amfs_auto_timeo[i] = -1;
+    gopt.amfs_auto_retrans[i] = -1; /* -1 means "never set before" */
+    gopt.amfs_auto_timeo[i] = -1; /* -1 means "never set before" */
   }
 
   /* cache duration */
