@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -87,7 +87,7 @@ am_ops amfs_toplvl_ops =
  ****************************************************************************/
 
 static void
-set_auto_attrcache_timeout(char *preopts, char *opts)
+set_auto_attrcache_timeout(char *preopts, char *opts, size_t l)
 {
 
 #ifdef MNTTAB_OPT_NOAC
@@ -98,8 +98,8 @@ set_auto_attrcache_timeout(char *preopts, char *opts)
    * automount points.
    */
   if (gopt.auto_attrcache == 0) {
-    sprintf(preopts, ",%s", MNTTAB_OPT_NOAC);
-    strcat(opts, preopts);
+    xsnprintf(preopts, l, ",%s", MNTTAB_OPT_NOAC);
+    xstrlcat(opts, preopts, l);
   }
 #endif /* MNTTAB_OPT_NOAC */
 
@@ -110,24 +110,24 @@ set_auto_attrcache_timeout(char *preopts, char *opts)
    * then we'll have to condition the remainder of this on OPT_NOAC.
    */
 #ifdef MNTTAB_OPT_ACTIMEO
-  sprintf(preopts, ",%s=%d", MNTTAB_OPT_ACTIMEO, gopt.auto_attrcache);
-  strcat(opts, preopts);
+  xsnprintf(preopts, l, ",%s=%d", MNTTAB_OPT_ACTIMEO, gopt.auto_attrcache);
+  xstrlcat(opts, preopts, l);
 #else /* MNTTAB_OPT_ACTIMEO */
 # ifdef MNTTAB_OPT_ACDIRMIN
-  sprintf(preopts, ",%s=%d", MNTTAB_OPT_ACTDIRMIN, gopt.auto_attrcache);
-  strcat(opts, preopts);
+  xsnprintf(preopts, l, ",%s=%d", MNTTAB_OPT_ACTDIRMIN, gopt.auto_attrcache);
+  xstrlcat(opts, preopts, l);
 # endif /* MNTTAB_OPT_ACDIRMIN */
 # ifdef MNTTAB_OPT_ACDIRMAX
-  sprintf(preopts, ",%s=%d", MNTTAB_OPT_ACTDIRMAX, gopt.auto_attrcache);
-  strcat(opts, preopts);
+  xsnprintf(preopts, l, ",%s=%d", MNTTAB_OPT_ACTDIRMAX, gopt.auto_attrcache);
+  xstrlcat(opts, preopts, l);
 # endif /* MNTTAB_OPT_ACDIRMAX */
 # ifdef MNTTAB_OPT_ACREGMIN
-  sprintf(preopts, ",%s=%d", MNTTAB_OPT_ACTREGMIN, gopt.auto_attrcache);
-  strcat(opts, preopts);
+  xsnprintf(preopts, l, ",%s=%d", MNTTAB_OPT_ACTREGMIN, gopt.auto_attrcache);
+  xstrlcat(opts, preopts, l);
 # endif /* MNTTAB_OPT_ACREGMIN */
 # ifdef MNTTAB_OPT_ACREGMAX
-  sprintf(preopts, ",%s=%d", MNTTAB_OPT_ACTREGMAX, gopt.auto_attrcache);
-  strcat(opts, preopts);
+  xsnprintf(preopts, l, ",%s=%d", MNTTAB_OPT_ACTREGMAX, gopt.auto_attrcache);
+  xstrlcat(opts, preopts, l);
 # endif /* MNTTAB_OPT_ACREGMAX */
 #endif /* MNTTAB_OPT_ACTIMEO */
 }
@@ -170,7 +170,7 @@ int
 amfs_toplvl_mount(am_node *mp, mntfs *mf)
 {
   struct stat stb;
-  char opts[256], preopts[256];
+  char opts[SIZEOF_OPTS], preopts[SIZEOF_OPTS], toplvl_opts[40];
   int error;
 
   /*
@@ -195,40 +195,45 @@ amfs_toplvl_mount(am_node *mp, mntfs *mf)
 
 #ifdef HAVE_FS_AUTOFS
   if (mf->mf_flags & MFF_IS_AUTOFS) {
-    autofs_get_opts(opts, mp->am_autofs_fh);
+    autofs_get_opts(opts, sizeof(opts), mp->am_autofs_fh);
   } else
 #endif /* HAVE_FS_AUTOFS */
   {
     preopts[0] = '\0';
 #ifdef MNTTAB_OPT_INTR
-    strcat(preopts, MNTTAB_OPT_INTR);
-    strcat(preopts, ",");
+    xstrlcat(preopts, MNTTAB_OPT_INTR, sizeof(preopts));
+    xstrlcat(preopts, ",", sizeof(preopts));
 #endif /* MNTTAB_OPT_INTR */
 #ifdef MNTTAB_OPT_IGNORE
-    strcat(preopts, MNTTAB_OPT_IGNORE);
-    strcat(preopts, ",");
+    xstrlcat(preopts, MNTTAB_OPT_IGNORE, sizeof(preopts));
+    xstrlcat(preopts, ",", sizeof(preopts));
 #endif /* MNTTAB_OPT_IGNORE */
-#ifdef WANT_TIMEO_AND_RETRANS_ON_TOPLVL
-    sprintf(opts, "%s%s,%s=%d,%s=%d,%s=%d,%s,map=%s",
-#else /* WANT_TIMEO_AND_RETRANS_ON_TOPLVL */
-    sprintf(opts, "%s%s,%s=%d,%s,map=%s",
-#endif /* WANT_TIMEO_AND_RETRANS_ON_TOPLVL */
-	    preopts,
-	    MNTTAB_OPT_RW,
-	    MNTTAB_OPT_PORT, nfs_port,
-#ifdef WANT_TIMEO_AND_RETRANS_ON_TOPLVL
-	    /* note: TIMEO+RETRANS for toplvl are only "udp" currently */
-	    MNTTAB_OPT_TIMEO, gopt.amfs_auto_timeo[AMU_TYPE_UDP],
-	    MNTTAB_OPT_RETRANS, gopt.amfs_auto_retrans[AMU_TYPE_UDP],
-#endif /* WANT_TIMEO_AND_RETRANS_ON_TOPLVL */
-	    mf->mf_ops->fs_type, mf->mf_info);
+    /* write most of the initial options + preopts */
+    xsnprintf(opts, sizeof(opts), "%s%s,%s=%d,%s,map=%s",
+	      preopts,
+	      MNTTAB_OPT_RW,
+	      MNTTAB_OPT_PORT, nfs_port,
+	      mf->mf_ops->fs_type, mf->mf_info);
+
+    /* process toplvl timeo/retrans options, if any */
+    if (gopt.amfs_auto_timeo[AMU_TYPE_TOPLVL] > 0) {
+      xsnprintf(toplvl_opts, sizeof(toplvl_opts), ",%s=%d",
+		MNTTAB_OPT_TIMEO, gopt.amfs_auto_timeo[AMU_TYPE_TOPLVL]);
+      xstrlcat(opts, toplvl_opts, sizeof(opts));
+    }
+    if (gopt.amfs_auto_retrans[AMU_TYPE_TOPLVL] > 0) {
+      xsnprintf(toplvl_opts, sizeof(toplvl_opts), ",%s=%d",
+		MNTTAB_OPT_RETRANS, gopt.amfs_auto_retrans[AMU_TYPE_TOPLVL]);
+      xstrlcat(opts, toplvl_opts, sizeof(opts));
+    }
+
 #ifdef MNTTAB_OPT_NOAC
     if (gopt.auto_attrcache == 0) {
-      strcat(opts, ",");
-      strcat(opts, MNTTAB_OPT_NOAC);
+      xstrlcat(opts, ",", sizeof(opts));
+      xstrlcat(opts, MNTTAB_OPT_NOAC, sizeof(opts));
     } else
 #endif /* MNTTAB_OPT_NOAC */
-      set_auto_attrcache_timeout(preopts, opts);
+      set_auto_attrcache_timeout(preopts, opts, sizeof(preopts));
   }
 
   /* now do the mount */
