@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1999-2003 Ion Badulescu
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -143,7 +143,7 @@ xdr_umntrequest(XDR *xdrs, umntrequest *objp)
   if (amuDebug(D_XDRTRACE))
     plog(XLOG_DEBUG, "xdr_umntrequest:");
 
-  if (!xdr_int(xdrs, &objp->isdirect))
+  if (!xdr_int(xdrs, (int *) &objp->isdirect))
     return (FALSE);
 
   if (!xdr_u_int(xdrs, (u_int *) &objp->devid))
@@ -346,7 +346,7 @@ autofs_program_1(struct svc_req *rqstp, SVCXPRT *transp)
     return;
   }
 
-  memset((char *)&result, 0, sizeof (result));
+  memset((char *)&result, 0, sizeof(result));
   ret = (*local) (&argument, &result, rqstp, transp);
 
   current_transp = NULL;
