@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mount_irix6.c,v 1.4.2.5 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/mount/mount_irix6.c
  *
  */
 
@@ -95,5 +94,17 @@ mount_irix(char *fsname, char *dir, int flags, MTYPE_TYPE type, voidp data)
 		 type, (efs_args_t *) data, sizeof(efs_args_t));
 #endif /* HAVE_FS_EFS */
 
+#ifdef HAVE_FS_AUTOFS
+  if (STREQ(type, MOUNT_TYPE_AUTOFS))
+    return mount(fsname, dir, (MNT2_GEN_OPT_FSS | MNT2_GEN_OPT_DATA | flags),
+		 type, (autofs_args_t *) data, sizeof(autofs_args_t));
+#endif /* HAVE_FS_AUTOFS */
+
+#ifdef HAVE_FS_LOFS
+  if (STREQ(type, MOUNT_TYPE_LOFS))
+    return mount(fsname, dir, (MNT2_GEN_OPT_FSS | MNT2_GEN_OPT_DATA | flags),
+		 type, (char *) NULL, 0);
+#endif /* HAVE_FS_LOFS */
+
   return EINVAL;
 }
