@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: mount_svr4.c,v 1.4.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/mount/mount_svr4.c
  *
  */
 
@@ -83,8 +82,7 @@ mount_svr4(char *fsname, char *dir, int flags, MTYPE_TYPE type, caddr_t data, co
    * Save a copy of the mount options.  The kernel will overwrite them with
    * those it recognizes.
    */
-  strncpy(mountopts, optstr, sizeof(mountopts));
-  mountopts[MAX_MNTOPT_STR-1] = '\0';
+  xstrlcpy(mountopts, optstr, MAX_MNTOPT_STR);
 #endif /* defined(MNT2_GEN_OPT_OPTIONSTR) && defined(MAX_MNTOPT_STR) */
 
 #if defined(MOUNT_TYPE_NFS3) && defined(MNTTAB_TYPE_NFS3)
@@ -101,6 +99,13 @@ mount_svr4(char *fsname, char *dir, int flags, MTYPE_TYPE type, caddr_t data, co
   }
 #endif /* defined(MOUNT_TYPE_NFS) && defined(MNTTAB_TYPE_NFS) */
 
+#if defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS)
+  if (STREQ(type, MOUNT_TYPE_AUTOFS)) {
+    return sys_mount(fsname, dir, (MNT2_GEN_OPT_DATA | flags),
+		     type, (char *) data, sizeof(autofs_args_t));
+  }
+#endif /* defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS) */
+
 #if defined(MOUNT_TYPE_UFS) && defined(MNTTAB_TYPE_UFS)
   if (STREQ(type, MOUNT_TYPE_UFS))
     return sys_mount(fsname, dir, (MNT2_GEN_OPT_DATA | flags),
@@ -145,5 +150,13 @@ mount_svr4(char *fsname, char *dir, int flags, MTYPE_TYPE type, caddr_t data, co
 # endif /* defined(MOUNT_TYPE_CACHEFS) && defined(MNTTAB_TYPE_CACHEFS) */
 #endif /*HAVE_FS_CACHEFS */
 
+#ifdef HAVE_FS_AUTOFS
+# if defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS)
+  if (STREQ(type, MOUNT_TYPE_AUTOFS))
+    return sys_mount(fsname, dir, (MNT2_GEN_OPT_DATA | flags),
+		     type, (char *) data, sizeof(autofs_args_t));
+# endif /* defined(MOUNT_TYPE_AUTOFS) && defined(MNTTAB_TYPE_AUTOFS) */
+#endif /* HAVE_FS_AUTOFS */
+
   return EINVAL;
 }
