@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -37,7 +37,7 @@
  * SUCH DAMAGE.
  *
  *
- * File: am-utils/conf/nfs_prot/nfs_prot_aix5_2.h
+ * File: am-utils/conf/nfs_prot/nfs_prot_aix4_3.h
  *
  */
 
@@ -46,7 +46,7 @@
 
 
 /*
- * AIX 5.2 has a different aix5_nfs_args structure, hence the separate header.
+ * AIX 4.3 and newer support NFS V.3, hence the separate header.
  */
 
 #ifdef HAVE_RPCSVC_NFS_PROT_H
@@ -62,18 +62,9 @@
 # include <sys/fs/nfs.h>
 #endif /* HAVE_SYS_FS_NFS_H */
 #ifdef HAVE_RPCSVC_MOUNT_H
-/*
- * AIX 5.2 wants 'struct pathcnf', but I couldn't find its definition
- * anywhere.  Luckily, amd doesn't need the size of this structure in
- * any other structure that it uses.  So we sidestep it for now.
- */
-struct pathcnf;
 # include <rpcsvc/mount.h>
 #endif /* HAVE_RPCSVC_MOUNT_H */
-#ifdef HAVE_SYS_VFS_H
-/* AIX 5.3 (ppc) wants definition of kernel-specific structure */
-struct thread_credentials;
-#endif /* HAVE_SYS_VFS_H */
+
 
 /*
  * MACROS
@@ -86,94 +77,6 @@ struct thread_credentials;
 # define MNTNAMLEN 255
 #endif /* not MNTNAMLEN */
 
-/* compatible macro name with other OSs */
-#ifdef UVMNT_FORCE
-# define MS_FORCE UVMNT_FORCE
-#endif /* UVMNT_FORCE */
-
-/********************************************************************************/
-/*
- * NFS mount option flags (out of mount.h)
- * Maybe one day IBM will include them in system headers.
- */
-#ifndef MNTOPT_ACDIRMAX
-# define MNTOPT_ACDIRMAX "acdirmax" /* max ac timeout for dirs (sec) */
-# define MNTOPT_ACDIRMIN "acdirmin" /* min ac timeout for dirs (sec) */
-# define MNTOPT_ACREGMAX "acregmax" /* max ac timeout for reg files (sec) */
-# define MNTOPT_ACREGMIN "acregmin" /* min ac timeout for reg files (sec) */
-# define MNTOPT_ACTIMEO  "actimeo" /* attr cache timeout (sec) */
-# define MNTOPT_BG       "bg" /* mount op in background if 1st attempt fails */
-# define MNTOPT_FASTATTR "fastattr" /* no sync_vp in nfs3_getattr */
-# define MNTOPT_FG       "fg" /* mount op in fg if 1st attempt fails, default */
-# define MNTOPT_GRPID    "grpid" /* SysV-compatible group-id on create */
-# define MNTOPT_HARD     "hard"  /* hard mount (default) */
-# define MNTOPT_INTR     "intr"  /* allow interrupts on hard mount */
-# define MNTOPT_NOAC     "noac"  /* don't cache file attributes */
-# define MNTOPT_NOACL	"noacl"  /* don't read acl's from server - default */
-# define MNTOPT_ACL	"acl"  /* read acl's from server means we load ksec */
-# define MNTOPT_NOAUTO   "noauto"/* hide entry from mount -a */
-# define MNTOPT_NOCTO    "nocto" /* no "close to open" attr consistency */
-# define MNTOPT_NODEV    "nodev" /*don't allow opening of devices accross mount*/
-# define MNTOPT_NOINTR   "nointr" /* don't allow interrupts on hard mounts */
-# define MNTOPT_NOQUOTA  "noquota" /* don't check quotas */
-# define MNTOPT_NOSUID   "nosuid" /* no set uid allowed */
-# define MNTOPT_BSY	"bsy"
-# define MNTOPT_PORT     "port"  /* server IP port number */
-# define MNTOPT_POSIX    "posix" /* ask for static pathconf values from mountd */
-# define MNTOPT_QUOTA    "quota" /* quotas */
-# define MNTOPT_RETRANS  "retrans" /* set number of request retries */
-# define MNTOPT_RETRYS   "retry" /* # of times mount is attempted, def=10000*/
-# define MNTOPT_RMNT     "remount" /* remount to rw if mode ro */
-# define MNTOPT_RO       "ro"    /* read only */
-# define MNTOPT_RSIZE    "rsize" /* set read size (bytes) */
-# define MNTOPT_RW       "rw"    /* read/write */
-# define MNTOPT_SECURE   "secure"/* use secure RPC for NFS */
-# define MNTOPT_SHORTDEV "shortdev" /* server dev */
-# define MNTOPT_SOFT     "soft"  /* soft mount */
-# define MNTOPT_TIMEO    "timeo" /* set initial timeout (1/10 sec) */
-# define MNTOPT_WSIZE    "wsize" /* set write size (bytes) */
-# define MNTOPT_VERS "vers"      /* protocol version number indicator */
-# define MNTOPT_PROTO    "proto"     /* protocol network_id indicator */
-# define MNTOPT_LLOCK    "llock"     /* Local locking (no lock manager) */
-# define MNTOPT_BIODS    "biods"     /* max biods per mount */
-# define MNTOPT_EXTATTR  "extraattr" /* extended attribute usage */
-# define MNTOPT_COMBEHND "combehind" /* extended attribute usage */
-# define MNTOPT_NUMCLUST "numclust"  /* max numclust per mount */
-# define MNTOPT_NODIRCACHE   "nodircache"    /* No readdir cache */
-
-# define NFSMNT_NOACL    0x0     /* turn off acl support (not supported) */
-# define NFSMNT_SHORTDEV 0x0     /* server does not support 32-bit device no.
-                                   (not supported) */
-# define NFSMNT_SOFT	0x001	/* soft mount (hard is default) */
-# define NFSMNT_WSIZE	0x002	/* set write size */
-# define NFSMNT_RSIZE	0x004	/* set read size */
-# define NFSMNT_TIMEO	0x008	/* set initial timeout */
-# define NFSMNT_RETRANS	0x010	/* set number of request retrys */
-# define NFSMNT_HOSTNAME	0x020	/* set hostname for error printf */
-# define NFSMNT_INT	0x040	/* allow interrupts on hard mount */
-# define NFSMNT_NOAC	0x080	/* don't cache attributes */
-# define NFSMNT_ACREGMIN	0x0100	/* set min secs for file attr cache */
-# define NFSMNT_ACREGMAX	0x0200	/* set max secs for file attr cache */
-# define NFSMNT_ACDIRMIN	0x0400	/* set min secs for dir attr cache */
-# define NFSMNT_ACDIRMAX	0x0800	/* set max secs for dir attr cache */
-# define NFSMNT_SECURE	0x1000	/* secure mount */
-# define NFSMNT_NOCTO	0x2000	/* no close-to-open consistency */
-# define NFSMNT_KNCONF       0x4000  /* transport's knetconfig structure */
-# define NFSMNT_GRPID        0x8000  /* System V-style gid inheritance */
-# define NFSMNT_RPCTIMESYNC  0x10000 /* use RPC to do secure NFS time sync */
-# define NFSMNT_KERBEROS     0x20000 /* use kerberos credentials */
-# define NFSMNT_POSIX        0x40000 /* static pathconf kludge info */
-# define NFSMNT_LLOCK    0x80000 /* Local locking (no lock manager) */
-# define NFSMNT_ACL	0x100000	/* turn on acl support */
-# define NFSMNT_BIODS        0x200000 /* number of biods per mount */
-# define NFSMNT_EXTATTR      0x400000 /* extended attribute usage */
-# define NFSMNT_FASTATTR     0x800000 /* no sync_vp in nfs3_getattr */
-# define NFSMNT_COMBEHND     0x1000000 /* allow commit behind */
-# define NFSMNT_NUMCLUST     0x2000000 /* number of cluster per mount */
-# define NFSMNT_NODIRCACHE   0x4000000 /* No readdir cache */
-#endif /* not MNTOPT_ACDIRMAX */
-/********************************************************************************/
-
 /* map field names */
 #define ex_dir ex_name
 #define gr_name g_name
@@ -280,10 +183,6 @@ typedef struct groups *groups;
 typedef struct groups groupnode;
 typedef struct mountlist *mountlist;
 
-/*
- * If these definitions fail to compile on your AIX 5.2 system, be
- * sure you install all of the necessary header files.
- */
 typedef attrstat	nfsattrstat;
 typedef createargs	nfscreateargs;
 typedef dirlist		nfsdirlist;
@@ -319,15 +218,15 @@ typedef writeargs	nfswriteargs;
  */
 
 /*
- * AIX 5.2 has NFS V3, but it is undefined in the header files.
+ * AIX 4.3 has NFS V3, but it is undefined in the header files.
  * so I define everything that's needed for NFS V3 here.
  */
 #ifdef MNT_NFS3
 
-struct aix5_nfs_args {
+struct aix4_nfs_args {
   struct sockaddr_in addr;	/* file server address */
   struct sockaddr_in *syncaddr;	/* secure NFS time sync addr */
-  int proto;
+  int proto;			/* IPPROTO_TCP/IPPROTO_UDP ??? */
   char *hostname;		/* server's hostname */
   char *netname;		/* server's netname */
   caddr_t fh;			/* File handle to be mounted */
@@ -345,11 +244,64 @@ struct aix5_nfs_args {
   int numclust;			/* numclust per mount */
 };
 
+#if 0
+/* old structure we hand crafted. no longer needed */
+struct aix4_nfs_args {
+  struct sockaddr_in addr;	/* server address and port */
+  caddr_t u0;			/* ??? UNKNOWN ??? */
+  unsigned long proto;		/* IPPROTO_TCP/IPPROTO_UDP */
+  char *hostname;		/* pointer to hostname? */
+  char *netname;		/* pointer to netname? */
+  caddr_t fh;			/* pointer to NFS v3 fh? */
+  unsigned long flags;		/* flags */
+  unsigned long wsize;		/* wsize */
+  unsigned long rsize;		/* rsize */
+  unsigned long timeo;		/* timeo */
+  unsigned long retrans;	/* retrans */
+  unsigned long acregmin;	/* acregmin */
+  unsigned long acregmax;	/* acregmax */
+  unsigned long acdirmin;	/* acdirmin */
+  unsigned long acdirmax;	/* acdirmax */
+  unsigned long u14;		/* ??? UNKNOWN ??? */
+  struct pathcnf *pathconf;	/* pathconf */
+};
+#endif
+
+/*
+ * IBM is in dire need of taking a soft-eng class.
+ * They changed the API/ABI (namely the nfs3_args structure)
+ * in a service pack...
+ *
+ * All the following *_bis junk is here to try and deal with this idiocy.
+ */
+#define MOUNT_TYPE_NFS3_BIS 0x12344321
+struct aix4_nfs_args_bis {
+  struct sockaddr_in addr;	/* server address and port */
+  struct sockaddr_in *syncaddr;	/* secure NFS time sync addr */
+  int proto;			/* IPPROTO_TCP/IPPROTO_UDP ??? */
+  char *hostname;		/* pointer to hostname? */
+  char *netname;		/* pointer to netname? */
+  caddr_t fh;			/* pointer to NFS v3 fh? */
+  unsigned long flags;		/* flags */
+  unsigned long wsize;		/* wsize */
+  unsigned long rsize;		/* rsize */
+  unsigned long timeo;		/* timeo */
+  unsigned long retrans;	/* retrans */
+  unsigned long acregmin;	/* acregmin */
+  unsigned long acregmax;	/* acregmax */
+  unsigned long acdirmin;	/* acdirmin */
+  unsigned long acdirmax;	/* acdirmax */
+  unsigned long u14;		/* ??? UNKNOWN ??? */
+  struct ppathcnf *pathconf;	/* static pathconf kludge */
+  int biods;			/* biods per mount */
+  int numclust;			/* numclust per mount */
+};
+
 #endif /* MNT_NFS3 */
 
 /*
  **************************************************************************
- * AIX 5.2's autofs is not ported or tested yet...
+ * AIX 4.3's autofs is not ported or tested yet...
  * For now, undefine it or define dummy entries.
  **************************************************************************
  */
