@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_darwin.h,v 1.1.2.6 2005/01/03 20:56:13 ezk Exp $
+ * File: am-utils/conf/nfs_prot/nfs_prot_darwin.h
  *
  */
 
@@ -58,46 +57,6 @@
 # include <ufs/ufs/ufsmount.h>
 #endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
 
-#define MOUNTVERS3 ((unsigned long)(3))
-
-typedef struct {
-  u_int fhandle3_len;
-  char *fhandle3_val;
-} fhandle3;
-
-
-enum mountstat3 {
-  MNT3_OK = 0,
-  MNT3ERR_PERM = 1,
-  MNT3ERR_NOENT = 2,
-  MNT3ERR_IO = 5,
-  MNT3ERR_ACCES = 13,
-  MNT3ERR_NOTDIR = 20,
-  MNT3ERR_INVAL = 22,
-  MNT3ERR_NAMETOOLONG = 63,
-  MNT3ERR_NOTSUPP = 10004,
-        MNT3ERR_SERVERFAULT = 10006
-};
-typedef enum mountstat3 mountstat3;
-
-struct mountres3_ok {
-  fhandle3 fhandle;
-  struct {
-    u_int auth_flavors_len;
-    int *auth_flavors_val;
-  } auth_flavors;
-};
-typedef struct mountres3_ok mountres3_ok;
-
-struct mountres3 {
-  mountstat3 fhs_status;
-  union {
-    mountres3_ok mountinfo;
-  } mountres3_u;
-};
-typedef struct mountres3 mountres3;
-
-
 /*
  * MACROS:
  */
@@ -215,45 +174,11 @@ typedef symlinkargs nfssymlinkargs;
 typedef writeargs nfswriteargs;
 
 
-/*
- *
- * FreeBSD-3.0-RELEASE has NFS V3.  Older versions had it only defined
- * in the rpcgen source file.  If you are on an older system, and you
- * want NFSv3 support, you need to regenerate the rpcsvc header files as
- * follows:
- *	cd /usr/include/rpcsvc
- *	rpcgen -h -C -DWANT_NFS3 mount.x
- *	rpcgen -h -C -DWANT_NFS3 nfs_prot.x
- * If you don't want NFSv3, then you will have to turn off the NFSMNT_NFSV3
- * macro below.  If the code doesn't compile, upgrade to the latest 3.0
- * version...
- */
 #ifdef NFSMNT_NFSV3
 
 # define MOUNT_NFS3	"nfs"	/* is this right? */
 # define MNTOPT_NFS3	"nfs"
 
-/*
- * as of 3.0-RELEASE the nfs_fh3 that is defined in the system headers
- * (or the one generated by rpcgen) lacks the proper full definition,
- * listed below.  A special macro (m4/macros/struct_nfs_fh3.m4) searches
- * for this special name before other names.
- */
-
-#define NFS3_FHSIZE 64
-#define FHSIZE3 64
-
-struct nfs_fh3_freebsd3 {
-  u_int fh3_length;
-  union nfs_fh3_u {
-    struct nfs_fh3_i {
-      fhandle_t fh3_i;
-    } nfs_fh3_i;
-    char data[NFS3_FHSIZE];
-  } fh3_u;
-};
-typedef struct nfs_fh3_freebsd3 nfs_fh3;
-
 #endif /* NFSMNT_NFSV3 */
 
 #endif /* not _AMU_NFS_PROT_H */
