@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -51,10 +51,6 @@
 
 struct netconfig *nfsncp;
 
-/* provide a definition for systems that don't have this */
-#ifndef INADDR_LOOPBACK
-# define INADDR_LOOPBACK	0x7f000001
-#endif /* not INADDR_LOOPBACK */
 
 /*
  * find the IP address that can be used to connect to the local host
@@ -299,7 +295,9 @@ amu_svc_getcaller(SVCXPRT *xprt)
  * register an RPC server
  */
 int
-amu_svc_register(SVCXPRT *xprt, u_long prognum, u_long versnum, void (*dispatch)(), u_long protocol, struct netconfig *ncp)
+amu_svc_register(SVCXPRT *xprt, u_long prognum, u_long versnum,
+		 void (*dispatch)(struct svc_req *rqstp, SVCXPRT *xprt),
+		 u_long protocol, struct netconfig *ncp)
 {
   return svc_reg(xprt, prognum, versnum, dispatch, ncp);
 }
@@ -838,7 +836,8 @@ out:
  * Register the autofs service for amd
  */
 int
-register_autofs_service(char *autofs_conftype, void (*autofs_dispatch)())
+register_autofs_service(char *autofs_conftype,
+			void (*autofs_dispatch)(struct svc_req *rqstp, SVCXPRT *xprt))
 {
   struct t_bind *tbp = 0;
   struct netconfig *autofs_ncp;
