@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2005 Erez Zadok
+ * Copyright (c) 1997-2006 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -942,11 +942,11 @@ xdr_am_mountres3_ok(XDR *xdrs, am_mountres3_ok *objp)
   if (!xdr_am_fhandle3(xdrs, &objp->fhandle))
     return (FALSE);
   if (!xdr_array(xdrs,
-		 (char **)&objp->auth_flavors.auth_flavors_val,
+		 (char **) ((voidp) &objp->auth_flavors.auth_flavors_val),
 		 (u_int *) &objp->auth_flavors.auth_flavors_len,
 		 ~0,
-		 sizeof (int),
-		 (xdrproc_t) xdr_int))
+		 sizeof(int),
+		 (XDRPROC_T_TYPE) xdr_int))
     return (FALSE);
   return (TRUE);
 }
